import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';

import '../knt_shimmer.dart';
import 'knt_default_image.dart';

class KntCachedImage extends StatelessWidget {
  const KntCachedImage({
    Key? key,
    this.url,
    this.width,
    this.height,
    this.borderRadius,
    this.border,
    this.boxShadows,
    this.padding,
    this.child,
    this.fit,
    this.placeholder,
    this.errorImage,
    this.httpHeaders,
  }) : super(key: key);

  final String? url;
  final double? width;
  final double? height;
  final BorderRadius? borderRadius;
  final Border? border;
  final List<BoxShadow>? boxShadows;
  final EdgeInsets? padding;
  final Widget? child;
  final BoxFit? fit;
  final Widget? placeholder;
  final Widget? errorImage;
  final Map<String, String>? httpHeaders;

  static Map<String, String>? defaultImageHeaders = {};

  @override
  Widget build(BuildContext context) {
    final defaultImage = KntDefaultImage(
      width: width,
      height: height,
      borderRadius: borderRadius,
      border: border,
      boxShadows: boxShadows,
    );
    return SizedBox(
      width: width,
      height: height,
      child: url?.isNotEmpty == true
          ? CachedNetworkImage(
              imageUrl: url!,
              httpHeaders: httpHeaders ?? defaultImageHeaders,
              placeholder: (context, url) =>
                  placeholder ??
                  KntShimmer(
                    width: width,
                    height: height,
                    borderRadius: borderRadius,
                    border: border,
                    boxShadows: boxShadows,
                  ),
              errorWidget: (context, url, _) => errorImage ?? defaultImage,
              imageBuilder: (context, imageProvider) => Container(
                width: width,
                height: height,
                padding: padding,
                decoration: BoxDecoration(
                  image: DecorationImage(
                    image: imageProvider,
                    fit: fit ?? BoxFit.cover,
                  ),
                  borderRadius: borderRadius,
                  border: border,
                  boxShadow: boxShadows,
                ),
                child: child,
              ),
            )
          : defaultImage,
    );
  }
}
