import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../config.dart';

class KntAppBar extends StatefulWidget implements PreferredSizeWidget {
  KntAppBar({
    Key? key,
    this.titlePage,
    this.customTitle,
    this.leadingIcon,
    this.trailingActions,
    this.textColor,
    this.backgroundColor,
    this.onPreDismiss,
  }) : super(key: key);

  /// Use this when we don't want to customize our own title widget
  final String? titlePage;
  final Widget? customTitle;
  final Widget? leadingIcon;
  final List<Widget>? trailingActions;
  final Color? textColor;
  final Color? backgroundColor;
  final VoidCallback? onPreDismiss;

  @override
  final Size preferredSize = Size(1.sw, 56.w);

  @override
  _KntAppBarState createState() => _KntAppBarState();
}

class _KntAppBarState extends State<KntAppBar> {
  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: widget.backgroundColor ?? KntUi.shared.primaryColor,
      automaticallyImplyLeading: false,
      centerTitle: true,
      leading: widget.leadingIcon != null
          ? IconButton(
              icon: widget.leadingIcon!,
              onPressed: () => _onDismiss(context),
            )
          : null,
      title: widget.customTitle ??
          Padding(
            padding: EdgeInsets.only(top: 4.w),
            child: Text(
              widget.titlePage ?? '',
              maxLines: 1,
              overflow: TextOverflow.ellipsis,
              style: TextStyle(
                color: widget.textColor ?? Colors.white,
                fontSize: 16.sp,
                height: 18.sp / 16.sp,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
      actions: widget.trailingActions,
    );
  }

  void _onDismiss(BuildContext context) {
    widget.onPreDismiss?.call();
    Navigator.of(context).pop();
  }
}

class KntDefaultAppBar extends StatelessWidget implements PreferredSizeWidget {
  KntDefaultAppBar({
    Key? key,
    this.titlePage,
    this.customTitle,
    this.trailingActions,
    this.onPreDismiss,
  }) : super(key: key);

  final String? titlePage;
  final Widget? customTitle;
  final List<Widget>? trailingActions;
  final VoidCallback? onPreDismiss;

  @override
  final Size preferredSize = Size(1.sw, 56.w);

  @override
  Widget build(BuildContext context) {
    return KntAppBar(
      titlePage: titlePage,
      customTitle: customTitle,
      leadingIcon: Icon(
        Icons.arrow_back_rounded,
        color: Colors.white,
        size: 20.w,
      ),
      trailingActions: trailingActions,
      onPreDismiss: onPreDismiss,
    );
  }
}

class KntExpandableAppBar extends StatelessWidget {
  const KntExpandableAppBar({
    this.title,
    this.expandedHeight,
    this.backgroundColor,
    this.leading,
    this.actions = const [],
    this.child,
  });

  final String? title;
  final double? expandedHeight;
  final Color? backgroundColor;
  final Widget? leading;
  final List<Widget> actions;
  final Widget? child;

  @override
  Widget build(BuildContext context) {
    return SliverAppBar(
      iconTheme: IconThemeData(color: Colors.white),
      backgroundColor: backgroundColor,
      expandedHeight: expandedHeight ?? 270.w,
      pinned: true,
      centerTitle: true,
      leading: leading ??
          IconButton(
            icon: Icon(
              Icons.arrow_back_rounded,
              color: Colors.white,
            ),
            onPressed: () => _onDismiss(context),
          ),
      title: Text(
        title ?? '',
        style: TextStyle(
          fontSize: 16.sp,
        ),
      ),
      actions: actions,
      flexibleSpace: FlexibleSpaceBar(
        background: Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.only(
              bottomLeft: Radius.circular(30.w),
            ),
          ),
          child: child,
        ),
      ),
    );
  }

  void _onDismiss(BuildContext context) {
    Navigator.of(context).pop();
  }
}

class KntDefaultExpandableAppBar extends StatelessWidget {
  const KntDefaultExpandableAppBar({
    Key? key,
    this.title,
    this.backgroundColor,
    this.child,
  }) : super(key: key);

  final String? title;
  final Color? backgroundColor;
  final Widget? child;

  @override
  Widget build(BuildContext context) {
    return KntExpandableAppBar(
      title: title,
      backgroundColor: backgroundColor,
      actions: [
        IconButton(
          icon: Icon(
            Icons.close,
            color: Colors.white,
          ),
          onPressed: () => _onDismiss(context),
        ),
      ],
      child: child,
    );
  }

  void _onDismiss(BuildContext context) {
    Navigator.of(context).pop();
  }
}
