import 'package:flutter/material.dart';
import 'package:package_info_plus/package_info_plus.dart';

import 'knt_expandable_widget.dart';

class KntAppInfo extends StatefulWidget {
  const KntAppInfo({
    Key? key,
    required this.builder,
  }) : super(key: key);

  final Widget Function({
    required String appName,
    required String version,
    required String buildNumber,
  }) builder;

  @override
  _KntAppInfoState createState() => _KntAppInfoState();
}

class _KntAppInfoState extends State<KntAppInfo> {
  late bool _loading;
  late bool _hasError;
  PackageInfo? _appInfo;

  @override
  void initState() {
    super.initState();
    _loading = true;
    _hasError = false;
    PackageInfo.fromPlatform().then((packageInfo) {
      setState(() {
        _appInfo = packageInfo;
        _loading = false;
      });
    }).onError((error, stackTrace) {
      _onError();
    });
  }

  @override
  Widget build(BuildContext context) {
    return KntExpandableWidget(
      expandedAtFirst: !_hasError,
      child: _hasError
          ? const SizedBox()
          : (_loading
              ? Center(
                  child: CircularProgressIndicator(),
                )
              : (_appInfo != null
                  ? widget.builder(
                      appName: _appInfo!.appName,
                      version: _appInfo!.version,
                      buildNumber: _appInfo!.buildNumber,
                    )
                  : const SizedBox())),
    );
  }

  void _onError() {
    if (!mounted) {
      return;
    }
    setState(() {
      _hasError = true;
    });
  }
}
