import 'package:device_preview/device_preview.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../config.dart';
import '../defined.dart';

typedef PreviewDeviceAppBuilder = Widget Function(BuildContext, Widget?);
typedef KntAppBuilder = Widget Function(
    BuildContext context, Locale?, PreviewDeviceAppBuilder?);

class KntAppWrapper extends StatelessWidget {
  const KntAppWrapper({
    Key? key,
    required this.appBuilder,
    required this.supportedLocales,
    this.localizedPath,
    this.debugShowPreviewDevice = true,
  }) : super(key: key);

  final KntAppBuilder appBuilder;
  final List<Locale> supportedLocales;
  final String? localizedPath;
  final bool debugShowPreviewDevice;

  @override
  Widget build(BuildContext context) {
    final fallbackLocale = supportedLocales.isNotEmpty
        ? supportedLocales.first
        : Locale(DefinedSetting.defaultLanguageCode);
    return EasyLocalization(
      supportedLocales: supportedLocales,
      path: localizedPath ?? DefinedSetting.localeAssetPath,
      fallbackLocale: fallbackLocale,
      child: ScreenUtilInit(
        designSize: Size(
          KntUi.shared.designWidth ?? DefinedUI.defaultDesignWidth,
          KntUi.shared.designHeight ?? DefinedUI.defaultDesignHeight,
        ),
        builder: (context, child) => GestureDetector(
          onTap: () {
            FocusManager.instance.primaryFocus?.unfocus();
          },
          child: DevicePreview(
            enabled: debugShowPreviewDevice,
            availableLocales: supportedLocales,
            builder: (context) => MediaQuery(
              data: MediaQuery.of(context).copyWith(
                textScaleFactor: DefinedUI.defaultFontScaleFactor,
              ),
              child: appBuilder.call(
                context,
                DevicePreview.locale(context),
                DevicePreview.appBuilder,
              ),
            ),
          ),
        ),
      ),
    );
  }
}
