import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../config.dart';

class KntButton extends StatelessWidget {
  const KntButton({
    Key? key,
    required this.child,
    this.needFullWidth = false,
    this.height,
    this.padding,
    this.leadingIcon,
    this.trailingIcon,
    this.backgroundColor,
    this.borderColor,
    this.borderWidth,
    this.borderRadius,
    this.onPressed,
  }) : super(key: key);

  final Widget child;
  final bool needFullWidth;
  final double? height;
  final EdgeInsets? padding;
  final Widget? leadingIcon;
  final Widget? trailingIcon;
  final Color? backgroundColor;
  final Color? borderColor;
  final double? borderWidth;
  final BorderRadius? borderRadius;
  final VoidCallback? onPressed;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onPressed,
      style: ElevatedButton.styleFrom(
        primary: backgroundColor ?? KntUi.shared.primaryColor,
        shape: RoundedRectangleBorder(
          borderRadius: borderRadius ?? BorderRadius.circular(3.w),
        ),
        side: borderColor == null
            ? null
            : BorderSide(
                color: borderColor!,
                width: borderWidth ?? 1.w,
              ),
      ),
      child: Container(
        width: needFullWidth ? 1.sw : null,
        height: height ?? 48.w,
        padding: padding ?? EdgeInsets.symmetric(vertical: 8.w),
        alignment: Alignment.center,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            if (leadingIcon != null) leadingIcon!,
            if (leadingIcon != null) SizedBox(width: 12.w),
            child,
            if (trailingIcon != null) SizedBox(width: 12.w),
            if (trailingIcon != null) trailingIcon!,
          ],
        ),
      ),
    );
  }
}

class KntSimpleButton extends KntButton {
  KntSimpleButton({
    required String title,
    TextStyle? textStyle,
    Color? textColor,
    super.needFullWidth = true,
    super.height,
    super.padding,
    super.leadingIcon,
    super.trailingIcon,
    super.backgroundColor,
    super.borderColor,
    super.borderWidth,
    super.borderRadius,
    super.onPressed,
  }) : super(
          child: Text(
            title,
            maxLines: 1,
            style: textStyle ??
                TextStyle(
                  color: textColor ?? Colors.white,
                  fontSize: 15.sp,
                  fontWeight: FontWeight.w700,
                  height: 15.sp / 15.sp,
                ),
          ),
        );
}
