import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../config.dart';
import 'knt_divider.dart';

class KntExpandableSection extends StatefulWidget {
  const KntExpandableSection({
    Key? key,
    this.expandedAtFirst,
    this.paddingVertical,
    this.paddingHorizontal,
    this.expandedIcon,
    this.collapsedIcon,
    this.summaryContent,
    this.unfoldedContent,
    this.backgroundColor,
    this.needDivider = false,
    this.needShadow = true,
  }) : super(key: key);

  final bool? expandedAtFirst;
  final double? paddingVertical;
  final double? paddingHorizontal;
  final Widget? expandedIcon;
  final Widget? collapsedIcon;
  final Widget? summaryContent;
  final Widget? unfoldedContent;
  final Color? backgroundColor;
  final bool needDivider;
  final bool needShadow;

  @override
  _KntExpandableSectionState createState() => _KntExpandableSectionState();
}

class _KntExpandableSectionState extends State<KntExpandableSection>
    with SingleTickerProviderStateMixin {
  late AnimationController _sizeChangeController;
  late bool _expanded;

  @override
  void initState() {
    super.initState();
    _expanded = widget.expandedAtFirst ?? false;
    _sizeChangeController = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 400),
    );
    _onAnimate();
  }

  @override
  void didUpdateWidget(covariant KntExpandableSection oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.expandedAtFirst != null && _expanded != widget.expandedAtFirst) {
      setState(() {
        _expanded = widget.expandedAtFirst ?? false;
      });
      _onAnimate();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
        top: widget.paddingVertical ?? 12.w,
        bottom: widget.paddingVertical ?? 12.w,
        left: widget.paddingHorizontal ?? 24.w,
      ),
      margin: EdgeInsets.symmetric(horizontal: 3.w),
      decoration: BoxDecoration(
        color: widget.backgroundColor,
        borderRadius: BorderRadius.circular(8.w),
        boxShadow: [
          if (widget.needShadow)
            BoxShadow(
              color: Colors.black12,
              offset: Offset(-1.w, 2.w),
              blurRadius: 3.w,
            ),
        ],
      ),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              Expanded(
                child: widget.summaryContent ?? const SizedBox(),
              ),
              SizedBox(width: 12.w),
              InkWell(
                onTap: _onTriggered,
                child: Container(
                  width: 36.w,
                  height: 36.w,
                  alignment: Alignment.centerRight,
                  child: _expanded
                      ? (widget.expandedIcon ??
                          Icon(
                            Icons.keyboard_arrow_up_sharp,
                            color: KntUi.shared.primaryColor,
                            size: 20.w,
                          ))
                      : (widget.collapsedIcon ??
                          Icon(
                            Icons.keyboard_arrow_down_sharp,
                            color: KntUi.shared.primaryColor,
                            size: 20.w,
                          )),
                ),
              ),
              SizedBox(width: widget.paddingHorizontal ?? 24.w),
            ],
          ),
          if (widget.unfoldedContent != null)
            SizeTransition(
              sizeFactor: CurvedAnimation(
                curve: Curves.fastOutSlowIn,
                parent: _sizeChangeController,
              ),
              child: Column(
                children: [
                  if (widget.needDivider)
                    SizedBox(height: widget.paddingVertical ?? 12.w),
                  if (widget.needDivider) const KntDivider(),
                  Padding(
                    padding: EdgeInsets.only(
                        right: widget.paddingHorizontal ?? 24.w),
                    child: widget.unfoldedContent ?? const SizedBox(),
                  ),
                ],
              ),
            ),
        ],
      ),
    );
  }

  void _onTriggered() {
    setState(() {
      _expanded = !_expanded;
    });
    _onAnimate();
  }

  void _onAnimate() {
    if (_expanded && _sizeChangeController.isDismissed) {
      _sizeChangeController.forward();
    } else if (!_expanded && _sizeChangeController.isCompleted) {
      _sizeChangeController.reverse();
    }
  }
}
