import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:knt_bloc/knt_bloc.dart';

import '../config.dart';
import 'image/knt_image.dart';
import 'knt_button.dart';

const _defaultBannerWidthRatio = 0.5;
const _defaultBannerHeightRatio = 0.6;

class KntDefaultIssuingWidget extends StatelessWidget {
  const KntDefaultIssuingWidget({
    Key? key,
    this.errorMessage,
    this.width,
    this.height,
    this.onRetry,
  })  : this.exception = null,
        super(key: key);

  const KntDefaultIssuingWidget.exception({
    Key? key,
    this.exception,
    this.width,
    this.height,
    this.onRetry,
  })  : this.errorMessage = null,
        super(key: key);

  final String? errorMessage;
  final KntException? exception;
  final double? width;
  final double? height;
  final VoidCallback? onRetry;

  @override
  Widget build(BuildContext context) {
    final localizedMessage = exception?.additionalInfo ?? (errorMessage ?? '');
    return KntIssuingWidget(
      width: width,
      height: height,
      customAssetBanner: 'packages/knt_ui/assets/images/bg_error_data.svg',
      customMessage: localizedMessage,
      onRetry: onRetry,
    );
  }
}

class KntIssuingWidget extends StatelessWidget {
  const KntIssuingWidget({
    Key? key,
    this.needLayoutHorizon = false,
    this.width,
    this.height,
    this.bannerWidthRatio = _defaultBannerWidthRatio,
    this.bannerHeightRatio = _defaultBannerHeightRatio,
    this.customAssetBanner,
    this.customMessage,
    this.retryText,
    this.onRetry,
    this.messageColor,
    this.imageFit,
  }) : super(key: key);

  final bool needLayoutHorizon;
  final double? width;
  final double? height;
  final String? customAssetBanner;
  final double bannerWidthRatio;
  final double bannerHeightRatio;
  final String? customMessage;
  final String? retryText;
  final VoidCallback? onRetry;
  final Color? messageColor;
  final BoxFit? imageFit;

  @override
  Widget build(BuildContext context) {
    final widgetWidth = width ?? 1.sw * _defaultBannerWidthRatio;
    final children = [
      if (customAssetBanner != null)
        KntImage.assets(
          uri: customAssetBanner!,
          width: widgetWidth,
          fit: imageFit ?? BoxFit.fitWidth,
        ),
      if (customMessage != null)
        Container(
          margin: EdgeInsets.only(top: 24.w),
          padding: EdgeInsets.symmetric(horizontal: 36.w),
          child: Center(
            child: Text(
              customMessage!,
              textAlign: TextAlign.center,
              style: TextStyle(
                color: messageColor ?? KntUi.shared.primaryColor,
                fontSize: 16.sp,
                fontWeight: FontWeight.w400,
                height: 22.sp / 16.sp,
              ),
            ),
          ),
        ),
      if (onRetry != null)
        Container(
          margin: EdgeInsets.only(top: 32.w),
          child: KntSimpleButton(
            onPressed: onRetry,
            title: retryText ?? '',
            trailingIcon: Icon(
              Icons.refresh_rounded,
              color: Colors.white,
              size: 24.w,
            ),
            borderRadius: BorderRadius.circular(24.w),
          ),
        ),
    ];
    return Container(
      width: width,
      height: height,
      alignment: Alignment.center,
      child: needLayoutHorizon
          ? Row(children: children)
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: children,
            ),
    );
  }
}
