import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../config.dart';

class KntBaseToolBar extends StatelessWidget {
  const KntBaseToolBar({
    Key? key,
    required this.titlePage,
    this.leadingIcon,
    this.trailingActions,
    this.decoration,
    this.titleColor,
    this.includeStatusBar = true,
  }) : super(key: key);

  final String titlePage;
  final Widget? leadingIcon;
  final List<Widget>? trailingActions;
  final BoxDecoration? decoration;
  final Color? titleColor;
  final bool includeStatusBar;

  @override
  Widget build(BuildContext context) {
    final topSpacing =
        includeStatusBar ? MediaQuery.of(context).padding.top : 0.0;
    return Container(
      width: 1.sw,
      height: 56.w + topSpacing,
      padding: EdgeInsets.only(
        top: topSpacing,
        left: 8.w,
        right: 8.w,
      ),
      decoration: decoration,
      child: Stack(
        children: [
          Container(
            height: 56.w,
            child: Row(
              children: [
                leadingIcon != null
                    ? InkWell(
                        onTap: () => _onDismiss(context),
                        child: leadingIcon!,
                      )
                    : const SizedBox(),
                const Spacer(),
                Row(
                  mainAxisAlignment: MainAxisAlignment.end,
                  children: trailingActions ?? [],
                ),
              ],
            ),
          ),
          Align(
            child: Text(
              titlePage,
              maxLines: 1,
              overflow: TextOverflow.ellipsis,
              style: TextStyle(
                color: titleColor ?? Colors.white,
                fontSize: 16.sp,
                height: 18.sp / 16.sp,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
        ],
      ),
    );
  }

  void _onDismiss(BuildContext context) {
    Navigator.of(context).pop();
  }
}

class KntToolBar extends StatelessWidget {
  const KntToolBar({
    Key? key,
    required this.titlePage,
    this.leadingIcon,
    this.trailingActions,
    this.backgroundColor,
    this.titleColor,
    this.includeStatusBar = true,
    this.needShadow = true,
  }) : super(key: key);

  final String titlePage;
  final Widget? leadingIcon;
  final List<Widget>? trailingActions;
  final Color? backgroundColor;
  final Color? titleColor;
  final bool includeStatusBar;
  final bool needShadow;

  @override
  Widget build(BuildContext context) {
    return KntBaseToolBar(
      titlePage: titlePage,
      leadingIcon: leadingIcon,
      trailingActions: trailingActions,
      decoration: BoxDecoration(
        color: backgroundColor ?? KntUi.shared.primaryColor,
        boxShadow: [
          if (needShadow)
            BoxShadow(
              color: Colors.black12.withAlpha(20),
              offset: Offset(-1.w, 1.w),
              blurRadius: 1.w,
              spreadRadius: 1.w,
            ),
        ],
      ),
      titleColor: titleColor,
      includeStatusBar: includeStatusBar,
    );
  }
}

class KntDefaultToolBar extends StatelessWidget {
  const KntDefaultToolBar({
    Key? key,
    required this.titlePage,
    this.trailingActions,
    this.includeStatusBar = true,
  }) : super(key: key);

  final String titlePage;
  final List<Widget>? trailingActions;
  final bool includeStatusBar;

  @override
  Widget build(BuildContext context) {
    return KntToolBar(
      titlePage: titlePage,
      leadingIcon: Padding(
        padding: EdgeInsets.all(12.w),
        child: Icon(
          Icons.arrow_back_rounded,
          color: Colors.white,
          size: 20.w,
        ),
      ),
      trailingActions: trailingActions,
    );
  }
}
