import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

import '../knt_app_bar.dart';
import '../knt_progress_bar.dart';
import '../knt_status_bar_page.dart';

class KntWebPage extends StatelessWidget {
  const KntWebPage({
    Key? key,
    required this.url,
    this.title,
  }) : super(key: key);

  final String url;
  final String? title;

  static void push(
    BuildContext context, {
    required String url,
    String? titlePage,
  }) {
    Navigator.of(context).push(MaterialPageRoute(builder: (context) {
      return KntWebPage(
        url: url,
        title: titlePage,
      );
    }));
  }

  @override
  Widget build(BuildContext context) {
    return KntWhiteStatusBarPage(
      page: Scaffold(
        backgroundColor: Colors.white,
        appBar: KntDefaultAppBar(
          titlePage: title,
        ),
        body: _Content(url: url),
      ),
    );
  }
}

class _Content extends StatefulWidget {
  const _Content({
    Key? key,
    required this.url,
  }) : super(key: key);

  final String url;

  @override
  _ContentState createState() => _ContentState();
}

class _ContentState extends State<_Content> {
  late bool _loading;

  @override
  void initState() {
    super.initState();
    _loading = true;
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        WebView(
          initialUrl: widget.url,
          javascriptMode: JavascriptMode.unrestricted,
          onPageStarted: _onPageStarted,
          onPageFinished: _onPageFinished,
        ),
        if (_loading)
          Align(
            child: KntProgressBar(),
          ),
      ],
    );
  }

  void _onPageStarted(String url) {
    setState(() {
      _loading = true;
    });
  }

  void _onPageFinished(String url) {
    setState(() {
      _loading = false;
    });
  }
}
